# PoliceLibrary

## 安装
首先安装库
```
pip install policelibrary
```

然后设置环境变量, 值从火山引擎上获取
```
export ARK_API_KEY=
export ASR_APP_KEY=
export ASR_ACCESS_KEY=
```

## 使用
### 聊天
```
python tests/test_chat.py
```
### 音频识别
```
python tests/test_asr.py
```